{ config, lib, pkgs, inputs, outputs, ... }:
let
in {
  nixpkgs = {
    # You can add overlays here
    overlays = [
      # Add overlays your own flake exports (from overlays and pkgs dir):
      outputs.overlays.additions
      outputs.overlays.modifications
      outputs.overlays.stable-packages

      # You can also add overlays exported from other flakes:
      # neovim-nightly-overlay.overlays.default

      # Or define it inline, for example:
      # (final: prev: {
      #   hi = final.hello.overrideAttrs (oldAttrs: {
      #     patches = [ ./change-hello-to-hi.patch ];
      #   });
      # })
    ];
    # Configure your nixpkgs instance
    config = {
      # Disable if you don't want unfree packages
      allowUnfree = true;
      # Workaround for https://github.com/nix-community/home-manager/issues/2942
      allowUnfreePredicate = _: true;
    };
  };

  nix = {
    package = lib.mkDefault pkgs.nix;
    settings = {
      experimental-features = [ "nix-command" "flakes" ];
      warn-dirty = false;
    };
  };
  programs = {
    home-manager.enable = true;
    git.enable = true;
    git = {
      userName = "m3tam3re";
      userEmail = "m@m3tam3re.com";
      aliases = { st = "status"; };
      extraConfig = {
        core.excludesfile = "~/.gitignore_global";
        init.defaultBranch = "master";
      };
    };
  };

  home = {
    username = lib.mkDefault "lkk-admin";
    homeDirectory = lib.mkDefault "/home/${config.home.username}";
  };
}
